@@ -1,24 +1,16 @@
 package Net::Amazon::S3::Request::GetBucketAccessControl;
-$Net::Amazon::S3::Request::GetBucketAccessControl::VERSION = '0.84';
+$Net::Amazon::S3::Request::GetBucketAccessControl::VERSION = '0.86';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
-extends 'Net::Amazon::S3::Request';
+extends 'Net::Amazon::S3::Request::Bucket';
 
 # ABSTRACT: An internal class to get a bucket's access control
 
-with 'Net::Amazon::S3::Role::Bucket';
+with 'Net::Amazon::S3::Request::Role::Query::Action::Acl';
+with 'Net::Amazon::S3::Request::Role::HTTP::Method::GET';
 
 __PACKAGE__->meta->make_immutable;
 
-sub http_request {
-    my $self = shift;
-
-    return $self->_build_http_request(
-        method => 'GET',
-        path   => $self->_uri('') . '?acl',
-    );
-}
-
 1;
 
 __END__
@@ -33,7 +25,7 @@ Net::Amazon::S3::Request::GetBucketAccessControl - An internal class to get a bu
 
 =head1 VERSION
 
-version 0.84
+version 0.86
 
 =head1 SYNOPSIS
 
@@ -60,7 +52,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
