@@ -1,5 +1,6 @@
 package Net::Amazon::S3::Request::Object;
-$Net::Amazon::S3::Request::Object::VERSION = '0.85';
+# ABSTRACT: Base class for all S3 Object operations
+$Net::Amazon::S3::Request::Object::VERSION = '0.86';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request::Bucket';
@@ -28,19 +29,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Request::Object
+Net::Amazon::S3::Request::Object - Base class for all S3 Object operations
 
 =head1 VERSION
 
-version 0.85
-
-=head1 DESCRIPTION
-
-Base class for all S3 Object operations
-
-=head1 NAME
-
-Net::Amazon::S3::Request::Object
+version 0.86
 
 =head1 AUTHOR
 
@@ -48,7 +41,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
