@@ -1,5 +1,6 @@
 package Net::Amazon::S3::Request::Role::Query::Param;
-$Net::Amazon::S3::Request::Role::Query::Param::VERSION = '0.85';
+# ABSTRACT: request query params role
+$Net::Amazon::S3::Request::Role::Query::Param::VERSION = '0.86';
 use MooseX::Role::Parameterized;
 
 parameter param => (
@@ -66,11 +67,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Request::Role::Query::Param
+Net::Amazon::S3::Request::Role::Query::Param - request query params role
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -78,7 +79,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
