@@ -1,5 +1,6 @@
 package Net::Amazon::S3::Request::Role::Query::Param::Max_keys;
-$Net::Amazon::S3::Request::Role::Query::Param::Max_keys::VERSION = '0.85';
+# ABSTRACT: max-keys query param role
+$Net::Amazon::S3::Request::Role::Query::Param::Max_keys::VERSION = '0.86';
 use Moose::Role;
 
 with 'Net::Amazon::S3::Request::Role::Query::Param' => {
@@ -20,11 +21,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Request::Role::Query::Param::Max_keys
+Net::Amazon::S3::Request::Role::Query::Param::Max_keys - max-keys query param role
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -32,7 +33,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
