@@ -1,5 +1,6 @@
 package Net::Amazon::S3::Request::Service;
-$Net::Amazon::S3::Request::Service::VERSION = '0.85';
+# ABSTRACT: Base class for all S3 Service operations
+$Net::Amazon::S3::Request::Service::VERSION = '0.86';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
@@ -16,19 +17,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Request::Service
+Net::Amazon::S3::Request::Service - Base class for all S3 Service operations
 
 =head1 VERSION
 
-version 0.85
-
-=head1 DESCRIPTION
-
-Base class for all S3 Service operations
-
-=head1 NAME
-
-Net::Amazon::S3::Request::Service
+version 0.86
 
 =head1 AUTHOR
 
@@ -36,7 +29,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
