@@ -1,9 +1,6 @@
-
-use strict;
-use warnings;
-
 package Net::Amazon::S3::Role::Bucket;
-$Net::Amazon::S3::Role::Bucket::VERSION = '0.85';
+# ABSTRACT: Bucket role
+$Net::Amazon::S3::Role::Bucket::VERSION = '0.86';
 use Moose::Role;
 use Scalar::Util;
 
@@ -40,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Role::Bucket
+Net::Amazon::S3::Role::Bucket - Bucket role
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -52,7 +49,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
