@@ -1,9 +1,6 @@
-#ABSTRACT: S3 Signature implementation base class
-use strict;
-use warnings;
-
 package Net::Amazon::S3::Signature;
-$Net::Amazon::S3::Signature::VERSION = '0.85';
+# ABSTRACT: S3 Signature implementation base class
+$Net::Amazon::S3::Signature::VERSION = '0.86';
 use Moose;
 
 has http_request => (
@@ -37,27 +34,21 @@ Net::Amazon::S3::Signature - S3 Signature implementation base class
 
 =head1 VERSION
 
-version 0.85
-
-=head1 NAME
-
-Net::Amazon::S3::Signature
+version 0.86
 
 =head1 METHODS
 
-=over
-
-=item new
+=head2 new
 
 Signature class should accept HTTPRequest instance and determine every
 required parameter via this instance
 
-=item sign_request( $request )
+=head2 sign_request( $request )
 
 Signature class should return authenticated request based on given parameter.
 Parameter can be modified.
 
-=item sign_uri( $request, $expires_at? )
+=head2 sign_uri( $request, $expires_at? )
 
 Signature class should return authenticated uri based on given request.
 
@@ -68,15 +59,13 @@ Default request date is current time.
 Signature class should accept provided C<< X-Amz-Date >> header instead (if signing request)
 or query parameter (if signing uri)
 
-=back
-
 =head1 AUTHOR
 
 Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
