@@ -1,9 +1,6 @@
-
-use strict;
-use warnings;
-
 package Net::Amazon::S3::Signature::V4;
-$Net::Amazon::S3::Signature::V4::VERSION = '0.85';
+# ABSTRACT: V4 signatures
+$Net::Amazon::S3::Signature::V4::VERSION = '0.86';
 use Moose;
 
 use Net::Amazon::S3::Signature::V4Implementation;
@@ -76,6 +73,12 @@ sub sign_request {
         $request->header( $Net::Amazon::S3::Signature::V4Implementation::X_AMZ_CONTENT_SHA256 => $sha->hexdigest );
     }
 
+    unless ($request->header ('x-amz-security-token')) {
+        my $aws_session_token = $self->http_request->s3->aws_session_token;
+        $request->header ('x-amz-security-token' => $aws_session_token)
+            if defined $aws_session_token;
+    }
+
     my $sign = $self->_sign( $region );
     $self->_host_to_region_host( $sign, $request );
     $sign->sign( $request );
@@ -102,11 +105,11 @@ __END__
 
 =head1 NAME
 
-Net::Amazon::S3::Signature::V4
+Net::Amazon::S3::Signature::V4 - V4 signatures
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -114,7 +117,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
