@@ -1,5 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Client;
-$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.85';
+# ABSTRACT: used for testing and as example
+$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.86';
 use strict;
 use warnings;
 
@@ -177,6 +178,7 @@ sub operation_object_create {
                 qw[ content_disposition  ],
                 qw[ content_encoding  ],
                 qw[ content_type  ],
+                qw[ encryption ],
                 qw[ expires ],
                 qw[ storage_class ],
                 qw[ user_metadata ],
@@ -218,11 +220,11 @@ __END__
 
 =head1 NAME
 
-Shared::Examples::Net::Amazon::S3::Client
+Shared::Examples::Net::Amazon::S3::Client - used for testing and as example
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -230,7 +232,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
