@@ -1,5 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Operation::Bucket::Create;
-$Shared::Examples::Net::Amazon::S3::Operation::Bucket::Create::VERSION = '0.85';
+# ABSTRACT: used for testing and as example
+$Shared::Examples::Net::Amazon::S3::Operation::Bucket::Create::VERSION = '0.86';
 use strict;
 use warnings;
 
@@ -27,11 +28,11 @@ __END__
 
 =head1 NAME
 
-Shared::Examples::Net::Amazon::S3::Operation::Bucket::Create
+Shared::Examples::Net::Amazon::S3::Operation::Bucket::Create - used for testing and as example
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 AUTHOR
 
@@ -39,7 +40,7 @@ Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2019 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
